@@ -24,6 +24,14 @@ class TinkoffInvestmentsTimeoutError(TinkoffInvestmentsError, TimeoutError):
     pass
 
 
+class TinkoffInvestmentsUnavailableError(TinkoffInvestmentsError):
+    pass
+
+
+class TinkoffInvestmentsConnectionError(TinkoffInvestmentsError):
+    pass
+
+
 class TinkoffInvestmentsAPIError(TinkoffInvestmentsError):
     def __init__(self, tracking_id: str, status: Status, error: Error):
         self.trackingId = tracking_id
@@ -41,4 +49,6 @@ __all__ = [
     'TinkoffInvestmentsUnauthorizedError',
     'TinkoffInvestmentsTooManyRequestsError',
     'TinkoffInvestmentsTimeoutError',
+    'TinkoffInvestmentsUnavailableError',
+    'TinkoffInvestmentsConnectionError',
 ]
